default_cli_hotkey_port_file

Function default_cli_hotkey_port_file 

pub fn default_cli_hotkey_port_file() -> PathBuf
Returns the default port file path used for CLI hotkey discovery.

We use the OS temp dir to avoid Unix socket path-length issues and because the file is ephemeral (only meaningful while a CLI session is running).